@@ -26,6 +26,9 @@ parser.add_argument('-f', '--fix_edges', help='fix edges in schema into db')
 parser.add_argument('-u', '--upgrade', help='upgrade')
 # this is getting bad and needs to be changed soon to something that's more extensible and makes more sense
 parser.add_argument('-d', '--downgrade', help='downgrade')
+# only applies when downgrading, default is deleting file since it's auto created by schema
+parser.add_argument('--keep_schema_files', action='store_true')
+parser.add_argument('--merge_branches', action='store_true')
 parser.add_argument('--history', help='alembic history', action='store_true')
 parser.add_argument('--current', help='alembic current', action='store_true')
 parser.add_argument('--show', help='show revision')
@@ -33,6 +36,9 @@ parser.add_argument('--heads', help='alembic heads', action='store_true')
 parser.add_argument('--branches', help='alembic branches', action='store_true')
 parser.add_argument('--stamp', help='alembic stamp')
 parser.add_argument('--edit', help='alembic edit')
+parser.add_argument('--merge', help='alembic merge')
+parser.add_argument('--message', help='message if alembic merge is called')
+parser.add_argument('--squash', help='squash the last N changes into one')
 parser.add_argument(
     '--changes', help='get changes in schema', action='store_true')
 
@@ -49,9 +55,10 @@ def main():
     else:
         r = Runner.from_command_line(metadata, args)
         if args.upgrade is not None:
-            r.upgrade(args.upgrade)
+            r.upgrade(revision=args.upgrade,
+                      merge_branches=args.merge_branches)
         elif args.downgrade is not None:
-            r.downgrade(args.downgrade)
+            r.downgrade(args.downgrade, not args.keep_schema_files)
         elif args.history is True:
             r.history()
         elif args.current is True:
@@ -68,6 +75,10 @@ def main():
             r.edit(args.edit)
         elif args.changes:
             r.changes()
+        elif args.merge is not None:
+            r.merge(args.merge, args.message)
+        elif args.squash is not None:
+            r.squash(args.squash)
         else:
             r.run()
 
